==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sr.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Приватност",
    "-" : "-",
    "Add external admin" : "Додајте спољног администратора",
    "Your files are not protected by encryption." : "Ваши фајлови нису заштићени шифровањем.",
    "Your data is located in: " : "Ваши подаци се налазе у:",
    "The admin hasn't selected the location of the server yet." : "Администратор још није означио локацију сервера.",
    "Please select a country" : "Одаберите државу",
    "You don't have any shares with individual users." : "Немате дељења са појединачним корисницима.",
    "Somaliland" : "Сомалиланд",
    "United Arab Emirates" : "Уједињени Арапски Емирати",
    "Afghanistan" : "Авганистан",
    "Albania" : "Албанија",
    "Armenia" : "Јерменија",
    "Angola" : "Ангола",
    "Argentina" : "Аргентина",
    "Austria" : "Аустрија",
    "Australia" : "Аустралија",
    "Azerbaijan" : "Азербејџан",
    "Bosnia and Herzegowina" : "Босна и Херцеговина",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгија",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "Бугарска",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Brunei" : "Брунеј",
    "Bolivia" : "Боливија",
    "Brazil" : "Бразил",
    "Bahamas" : "Бахами",
    "Bhutan" : "Бутан",
    "Botswana" : "Боцвана",
    "Belarus" : "Белорусија",
    "Belize" : "Белизе",
    "Canada" : "Канада",
    "Democratic Republic of the Congo" : "Демократска Република Конго",
    "Central African Republic" : "Централноафричка Република",
    "Congo" : "Конго",
    "Switzerland" : "Швајцарска",
    "Cote d'Ivoire" : "Обала Слоноваче",
    "Chile" : "Чиле",
    "Cameroon" : "Камерун",
    "China" : "Кина",
    "Colombia" : "Колумбија",
    "Costa Rica" : "Костарика",
    "Cuba" : "Куба",
    "Cyprus" : "Кипар",
    "Czech" : "Чешка",
    "Germany" : "Немачка",
    "Djibouti" : "Џибути",
    "Denmark" : "Данска",
    "Dominican Republic" : "Доминиканска Република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонија",
    "Egypt" : "Египат",
    "West Sahara" : "Западна Сахара",
    "Eritrea" : "Еритреја",
    "Spain" : "Шпанија",
    "Ethiopia" : "Етиопија",
    "Finland" : "Финска",
    "Fiji" : "Фиџи",
    "Falkland Islands" : "Фолкландска острва",
    "France" : "Француска",
    "Gabon" : "Габон",
    "United Kingdom" : "Уједињено Краљевство",
    "Georgia" : "Грузија",
    "Ghana" : "Гана",
    "Greenland" : "Гренланд",
    "Gambia" : "Гамбија",
    "Guinea" : "Гвинеја",
    "Equatorial Guinea" : "Екваторијална Гвинеја",
    "Greece" : "Грчка",
    "Guatemala" : "Гватемала",
    "Guinea-Bissau" : "Гвинеја Бисао",
    "Guyana" : "Гвајана",
    "Honduras" : "Хондурас",
    "Croatia" : "Хрватска",
    "Haiti" : "Хаити",
    "Hungary" : "Мађарска",
    "Indonesia" : "Индонезија",
    "Ireland" : "Ирска",
    "Israel" : "Израел",
    "India" : "Индија",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исланд",
    "Italy" : "Италија",
    "Jamaica" : "Јамајка",
    "Jordan" : "Јордан",
    "Japan" : "Јапан",
    "Kenya" : "Кенија",
    "Kyrgyzstan" : "Киргистан",
    "Cambodia" : "Камбоџа",
    "North Korea" : "Северна Кореја",
    "South Korea" : "Јужна Кореја",
    "Kuwait" : "Кувајт",
    "Kazakhstan" : "Казахстан",
    "Laos" : "Лаос",
    "Lebanon" : "Либан",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерија",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литванија",
    "Luxembourg" : "Луксембург",
    "Latvia" : "Летонија",
    "Libya" : "Либија",
    "Morocco" : "Мароко",
    "Moldova" : "Молдавија",
    "Montenegro" : "Црна Гора",
    "Madagascar" : "Мадагаскар",
    "Macedonia" : "Македонија",
    "Mali" : "Мали",
    "Myanmar" : "Мјанмар",
    "Mongolia" : "Монголија",
    "Mauritania" : "Мауританија",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малезија",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибија",
    "New Caledonia" : "Нова Каледонија",
    "Niger" : "Нигер",
    "Nigeria" : "Нигерија",
    "Nicaragua" : "Никарагва",
    "Netherlands" : "Холандија",
    "Norway" : "Норвешка",
    "Nepal" : "Непал",
    "New Zealand" : "Нови Зеланд",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "Papua New Guinea" : "Папуа Нова Гвинеја",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Пољска",
    "Puerto Rico" : "Порторико",
    "Portugal" : "Португалија",
    "Paraguay" : "Парагвај",
    "Qatar" : "Катар",
    "Romania" : "Румунија",
    "Serbia" : "Србија",
    "Russia" : "Русија",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудијска Арабија",
    "Solomon Islands" : "Соломонска Острва",
    "Sudan" : "Судан",
    "Sweden" : "Шведска",
    "Singapore" : "Сингапур",
    "Slovenia" : "Словенија",
    "Slovakia" : "Словачка",
    "Sierra Leone" : "Сијера Леоне",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалија",
    "Suriname" : "Суринам",
    "South Sudan" : "Јужни Судан",
    "El Salvador" : "Ел Салвадор",
    "Syria" : "Сирија",
    "Swaziland" : "Свазиленд",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Француске јужне и антарктичке земље",
    "Togo" : "Того",
    "Thailand" : "Тајланд",
    "Tajikistan" : "Таџикистан",
    "Timor-Leste" : "Источни Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Turkey" : "Турска",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Taiwan" : "Тајван",
    "Tanzania" : "Танзанија",
    "Ukraine" : "Украјина",
    "Uganda" : "Уганда",
    "United States" : "Сједињене Америчке Државе",
    "Uruguay" : "Уругвај",
    "Uzbekistan" : "Узбекистан",
    "Venezuela" : "Венецуела",
    "Vietnam" : "Вијетнам",
    "Vanuatu" : "Вануату",
    "Yemen" : "Јемен",
    "South Africa" : "Јужноафричка република",
    "Zambia" : "Замбија",
    "Zimbabwe" : "Зимбабве",
    "Your Nextcloud account" : "Ваш Некстклауд налог",
    "Learn more ↗" : "Сазнајте више ↗",
    "Where is your data?" : "Где су Ваши подаци?",
    "Who has access to your data?" : "Ко има приступ Вашим подацима?",
    "Administrators" : "Администратори",
    "People you shared with" : "Људи са којима делите",
    "Privacy policy" : "Политика приватност",
    "Read the privacy policy." : "Прочитајте политику приватности."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sr.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Приватност",
    "-" : "-",
    "Add external admin" : "Додајте спољног администратора",
    "Your files are not protected by encryption." : "Ваши фајлови нису заштићени шифровањем.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Ваши подаци су шифровани {linkopen}шифровањем на серверској страни ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Овај сервер је заштићен са шифровањем целог диска.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Ваши подаци су шифровани {linkopen}шифровањем на серверској страни ↗{linkclose}. Додатно, сервер се заштићен са шифровањем целог диска.",
    "This server is using full-disk-encryption." : "Овај сервер користи шифровање целог диска.",
    "Your data is located in: " : "Ваши подаци се налазе у:",
    "The admin hasn't selected the location of the server yet." : "Администратор још није означио локацију сервера.",
    "Please select a country" : "Одаберите државу",
    "You don't have any shares with individual users." : "Немате дељења са појединачним корисницима.",
    "Somaliland" : "Сомалиланд",
    "United Arab Emirates" : "Уједињени Арапски Емирати",
    "Afghanistan" : "Авганистан",
    "Albania" : "Албанија",
    "Armenia" : "Јерменија",
    "Angola" : "Ангола",
    "Argentina" : "Аргентина",
    "Austria" : "Аустрија",
    "Australia" : "Аустралија",
    "Azerbaijan" : "Азербејџан",
    "Bosnia and Herzegowina" : "Босна и Херцеговина",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгија",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "Бугарска",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Brunei" : "Брунеј",
    "Bolivia" : "Боливија",
    "Brazil" : "Бразил",
    "Bahamas" : "Бахами",
    "Bhutan" : "Бутан",
    "Botswana" : "Боцвана",
    "Belarus" : "Белорусија",
    "Belize" : "Белизе",
    "Canada" : "Канада",
    "Democratic Republic of the Congo" : "Демократска Република Конго",
    "Central African Republic" : "Централноафричка Република",
    "Congo" : "Конго",
    "Switzerland" : "Швајцарска",
    "Cote d'Ivoire" : "Обала Слоноваче",
    "Chile" : "Чиле",
    "Cameroon" : "Камерун",
    "China" : "Кина",
    "Colombia" : "Колумбија",
    "Costa Rica" : "Костарика",
    "Cuba" : "Куба",
    "Cyprus" : "Кипар",
    "Czech" : "Чешка",
    "Germany" : "Немачка",
    "Djibouti" : "Џибути",
    "Denmark" : "Данска",
    "Dominican Republic" : "Доминиканска Република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонија",
    "Egypt" : "Египат",
    "West Sahara" : "Западна Сахара",
    "Eritrea" : "Еритреја",
    "Spain" : "Шпанија",
    "Ethiopia" : "Етиопија",
    "Finland" : "Финска",
    "Fiji" : "Фиџи",
    "Falkland Islands" : "Фолкландска острва",
    "France" : "Француска",
    "Gabon" : "Габон",
    "United Kingdom" : "Уједињено Краљевство",
    "Georgia" : "Грузија",
    "Ghana" : "Гана",
    "Greenland" : "Гренланд",
    "Gambia" : "Гамбија",
    "Guinea" : "Гвинеја",
    "Equatorial Guinea" : "Екваторијална Гвинеја",
    "Greece" : "Грчка",
    "Guatemala" : "Гватемала",
    "Guinea-Bissau" : "Гвинеја Бисао",
    "Guyana" : "Гвајана",
    "Honduras" : "Хондурас",
    "Croatia" : "Хрватска",
    "Haiti" : "Хаити",
    "Hungary" : "Мађарска",
    "Indonesia" : "Индонезија",
    "Ireland" : "Ирска",
    "Israel" : "Израел",
    "India" : "Индија",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исланд",
    "Italy" : "Италија",
    "Jamaica" : "Јамајка",
    "Jordan" : "Јордан",
    "Japan" : "Јапан",
    "Kenya" : "Кенија",
    "Kyrgyzstan" : "Киргистан",
    "Cambodia" : "Камбоџа",
    "North Korea" : "Северна Кореја",
    "South Korea" : "Јужна Кореја",
    "Kuwait" : "Кувајт",
    "Kazakhstan" : "Казахстан",
    "Laos" : "Лаос",
    "Lebanon" : "Либан",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерија",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литванија",
    "Luxembourg" : "Луксембург",
    "Latvia" : "Летонија",
    "Libya" : "Либија",
    "Morocco" : "Мароко",
    "Moldova" : "Молдавија",
    "Montenegro" : "Црна Гора",
    "Madagascar" : "Мадагаскар",
    "Macedonia" : "Македонија",
    "Mali" : "Мали",
    "Myanmar" : "Мјанмар",
    "Mongolia" : "Монголија",
    "Mauritania" : "Мауританија",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малезија",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибија",
    "New Caledonia" : "Нова Каледонија",
    "Niger" : "Нигер",
    "Nigeria" : "Нигерија",
    "Nicaragua" : "Никарагва",
    "Netherlands" : "Холандија",
    "Norway" : "Норвешка",
    "Nepal" : "Непал",
    "New Zealand" : "Нови Зеланд",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "Papua New Guinea" : "Папуа Нова Гвинеја",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Пољска",
    "Puerto Rico" : "Порторико",
    "Portugal" : "Португалија",
    "Paraguay" : "Парагвај",
    "Qatar" : "Катар",
    "Romania" : "Румунија",
    "Serbia" : "Србија",
    "Russia" : "Русија",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудијска Арабија",
    "Solomon Islands" : "Соломонска Острва",
    "Sudan" : "Судан",
    "Sweden" : "Шведска",
    "Singapore" : "Сингапур",
    "Slovenia" : "Словенија",
    "Slovakia" : "Словачка",
    "Sierra Leone" : "Сијера Леоне",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалија",
    "Suriname" : "Суринам",
    "South Sudan" : "Јужни Судан",
    "El Salvador" : "Ел Салвадор",
    "Syria" : "Сирија",
    "Swaziland" : "Свазиленд",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Француске јужне и антарктичке земље",
    "Togo" : "Того",
    "Thailand" : "Тајланд",
    "Tajikistan" : "Таџикистан",
    "Timor-Leste" : "Источни Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Turkey" : "Турска",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Taiwan" : "Тајван",
    "Tanzania" : "Танзанија",
    "Ukraine" : "Украјина",
    "Uganda" : "Уганда",
    "United States" : "Сједињене Америчке Државе",
    "Uruguay" : "Уругвај",
    "Uzbekistan" : "Узбекистан",
    "Venezuela" : "Венецуела",
    "Vietnam" : "Вијетнам",
    "Vanuatu" : "Вануату",
    "Yemen" : "Јемен",
    "South Africa" : "Јужноафричка република",
    "Zambia" : "Замбија",
    "Zimbabwe" : "Зимбабве",
    "Your Nextcloud account" : "Ваш Некстклауд налог",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Ваши подаци представљају ко сте Ви и лако могу бити злоупотребљени. Ми у Некстклауду верујемо да имате права да изаберете шта се дешава са Вашим подацима. Некстклауд штити ваша права као што је дефинисано у манифесту корисничких података!",
    "User Data Manifesto 2.0" : "Манифест корисничких података 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Дефинише основна права људи да контролишу сопствене податке у доба интернета",
    "Control" : "Контрола",
    "over user data access" : "над приступом корисничким подацима",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Подаци који се експлицитно и својевољно отпреме од стране корисника морају бити под крајњом контролом тог корисника. Корисници треба да су у могућности да изаберу коме ће дати директан приступ подацима, и под којим дозволама и лиценцама ће такав приступ бити дат.",
    "Knowledge" : "Разумевање",
    "of how the data is stored" : "како се подаци складиште",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Када се подаци отпреме одређеном провајдеру сервиса, корисници морају бити упућени где тај провајдер држи податке, колико дуго, под чијом правном надлежности провајдер ради и који закони се примењују.",
    "Freedom" : "Слобода",
    "to choose a platform" : "одабира платформе",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Корисници морају увек бити у могућности да извуку своје податке са сервера без да искусе закључавање од стране продавца. Да би се ово гарантовало, неопходни су отворени формати и протоколи.",
    "Learn more ↗" : "Сазнајте више ↗",
    "Where is your data?" : "Где су Ваши подаци?",
    "Who has access to your data?" : "Ко има приступ Вашим подацима?",
    "Administrators" : "Администратори",
    "People you shared with" : "Људи са којима делите",
    "Privacy policy" : "Политика приватност",
    "Read the privacy policy." : "Прочитајте политику приватности.",
    "Encryption" : "Шифровање"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
